%global srcname numpy
%global _description \
NumPy is a general-purpose array-processing package designed to\
efficiently manipulate large multi-dimensional arrays of arbitrary\
records without sacrificing too much speed for small multi-dimensional\
arrays.  NumPy is built on the Numeric code base and adds features\
introduced by numarray as well as an extended C-API and the ability to\
create arrays of arbitrary type.\
\
There are also basic facilities for discrete fourier transform,\
basic linear algebra and random number generation.


Name:           python3-%{srcname}
Version:        1.10.4
Release:        7%{?dist}
Summary:        A fast multidimensional array facility for Python 3

# Everything is BSD except for class SafeEval in numpy/lib/utils.py which is Python
# MIT - numpy/random/mtrand
# PSFv2 - doc/scipy-sphinx-theme/_theme/scipy/static/js/copybutton.js (not shipped)
License:        BSD and Python
URL:            http://www.numpy.org/
Source0:        http://downloads.sourceforge.net/%{srcname}/%{srcname}-%{version}.tar.gz

BuildRequires:  lapack-devel
BuildRequires:  gcc-gfortran
BuildRequires:  atlas-devel

# Add input validation on empty list or ndarray in numpy.pad function.
# Fixes rhbz#1483689
Patch1:         0001-Security-fix-for-CVE-2017-12852.patch

%description %{_description}


%package -n python%{python3_pkgversion}-%{srcname}
Summary:        A fast multidimensional array facility for Python %{python3_version}

License:        BSD
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
BuildRequires:  python%{python3_pkgversion}-nose
%{?python_provide:%python_provide python%{python3_pkgversion}-%{srcname}}

%description -n python%{python3_pkgversion}-%{srcname} %{_description}

%package -n python%{python3_pkgversion}-%{srcname}-f2py
Summary:        f2py for %{srcname}
Requires:       python%{python3_pkgversion}-%{srcname} = %{version}-%{release}
Requires:       python%{python3_pkgversion}-devel
%{?python_provide:%python_provide python%{python3_pkgversion}-%{srcname}-f2py}

%description -n python%{python3_pkgversion}-%{srcname}-f2py
This package includes a version of f2py%{python3_version} that works properly with NumPy.


%package -n python%{python3_other_pkgversion}-%{srcname}
Summary:        A fast multidimensional array facility for Python %{python3_other_version}
License:        BSD
BuildRequires:  python%{python3_other_pkgversion}-devel
BuildRequires:  python%{python3_other_pkgversion}-setuptools
BuildRequires:  python%{python3_other_pkgversion}-nose

%description -n python%{python3_other_pkgversion}-%{srcname} %{_description}

%package -n python%{python3_other_pkgversion}-%{srcname}-f2py
Summary:        f2py for %{srcname}
Requires:       python%{python3_other_pkgversion}-%{srcname} = %{version}-%{release}
Requires:       python%{python3_other_pkgversion}-devel

%description -n python%{python3_other_pkgversion}-%{srcname}-f2py
This package includes a version of f2py%{python3_other_version} that works properly with NumPy.


%prep
%setup -q -n %{srcname}-%{version}
%patch1 -p1
# Strip shbang
find -name \*.py -exec sed -i -e '1{/^#!/d}' {} +
# workaround for rhbz#849713
# http://mail.scipy.org/pipermail/numpy-discussion/2012-July/063530.html
rm numpy/distutils/command/__init__.py && touch numpy/distutils/command/__init__.py

# Atlas 3.10 library names
cat >> site.cfg <<EOF
[atlas]
library_dirs = %{_libdir}/atlas
atlas_libs = satlas
EOF


%build
export ATLAS=%{_libdir}
export BLAS=%{_libdir}
export LAPACK=%{_libdir}
export CFLAGS="%{optflags}"
%py3_build
%py3_other_build


%install
export ATLAS=%{_libdir}
export FFTW=%{_libdir}
export BLAS=%{_libdir}
export LAPACK=%{_libdir}
export CFLAGS="%{optflags}"
# skip-build currently broken, this works around it for now
%{__python3} setup.py install --root %{buildroot}
%{__python3_other} setup.py install --root %{buildroot}

# Fix .so permissions
find %{buildroot} -name \*.so -exec chmod 755 {} +

install -D -p -m 0644 doc/f2py/f2py.1 %{buildroot}%{_mandir}/man1/f2py%{python3_version}.1
install -D -p -m 0644 doc/f2py/f2py.1 %{buildroot}%{_mandir}/man1/f2py%{python3_other_version}.1


%check
pushd doc &> /dev/null

PYTHONPATH="%{buildroot}%{python3_sitearch}" PATH=%{buildroot}%{_bindir}:$PATH \
  %{__python3} -c "import pkg_resources, numpy ; numpy.test(verbose=2)" \
%ifarch s390 s390x
|| :
%endif

PYTHONPATH="%{buildroot}%{python3_other_sitearch}" PATH=%{buildroot}%{_bindir}:$PATH \
  %{__python3_other} -c "import pkg_resources, numpy ; numpy.test(verbose=2)" \
%ifarch s390 s390x
|| :
%endif

# don't remove this comment
popd &> /dev/null


%files -n python%{python3_pkgversion}-%{srcname}
%license LICENSE.txt
%doc README.txt THANKS.txt DEV_README.txt COMPATIBILITY site.cfg.example
%{python3_sitearch}/%{srcname}/__pycache__
%{python3_sitearch}/%{srcname}
%exclude %{python3_sitearch}/%{srcname}/f2py
%{python3_sitearch}/%{srcname}-%{version}-py%{python3_version}.egg-info

%files -n python%{python3_pkgversion}-%{srcname}-f2py
%{_bindir}/f2py%{python3_version}
%{_mandir}/man1/f2py%{python3_version}.1*
%{python3_sitearch}/%{srcname}/f2py


%files -n python%{python3_other_pkgversion}-%{srcname}
%license LICENSE.txt
%doc README.txt THANKS.txt DEV_README.txt COMPATIBILITY site.cfg.example
%{python3_other_sitearch}/%{srcname}/__pycache__
%{python3_other_sitearch}/%{srcname}
%exclude %{python3_other_sitearch}/%{srcname}/f2py
%{python3_other_sitearch}/%{srcname}-%{version}-py%{python3_other_version}.egg-info

%files -n python%{python3_other_pkgversion}-%{srcname}-f2py
%{_bindir}/f2py%{python3_other_version}
%{_mandir}/man1/f2py%{python3_other_version}.1*
%{python3_other_sitearch}/%{srcname}/f2py


%changelog
* Thu Mar 07 2019 Troy Dawson <tdawson@redhat.com>
- Rebuilt to change main python from 3.4 to 3.6

* Fri Jul 13 2018 Carl George <carl@george.computer> - 1.10.4-6
- Enable python36 subpackage

* Wed Sep 13 2017 Iryna Shcherbina <ishcherb@redhat.com> - 1.10.4-5
- Add a patch for the security vulnerability (rhbz#1483689)

* Tue Mar 1 2016 Orion Poplawski <orion@cora.nwra.com> - 1.10.4-4
- Strip shbangs and fix .so permissions

* Fri Feb 26 2016 Orion Poplawski <orion@cora.nwra.com> - 1.10.4-3
- Drop epoch
- Drop BR Cython

* Thu Feb 25 2016 Orion Poplawski <orion@cora.nwra.com> - 1.10.4-2
- Add missing BuildRequires

* Mon Jan 11 2016 Orion Poplawski <orion@cora.nwra.com> - 1.10.4-1
- Initial EPEL7 package
